GlFramebufferTexture2D typedef

GlFramebufferTexture2D = void Function(int target, int index, int buffer, int offset, int size)

Implementation

typedef GlFramebufferTexture2D = void Function(
    int target, int attachment, int textarget, int texture, int level);