GlFramebufferTextureLayer typedef

GlFramebufferTextureLayer = void Function(int target, int index, int buffer, int offset, int size)

Implementation

typedef GlFramebufferTextureLayer = void Function(
    int target, int attachment, int texture, int level, int layer);