GlNamedFramebufferTextureLayer typedef

GlNamedFramebufferTextureLayer = void Function(int target, int index, int buffer, int offset, int size)

Implementation

typedef GlNamedFramebufferTextureLayer = void Function(
    int framebuffer, int attachment, int texture, int level, int layer);