OpenGLEXTConstant class

Implementers

Constructors

OpenGLEXTConstant()

Properties

hashCode → int
The hash code for this object.
no setterinherited
MAX_TEXTURE_MAX_ANISOTROPY_EXT ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
TEXTURE_MAX_ANISOTROPY_EXT ↔ int
getter/setter pair
UNPACK_FLIP_Y_WEBGL ↔ int
getter/setter pair
UNPACK_PREMULTIPLY_ALPHA_WEBGL ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited